import dotenv from 'dotenv'
import { SlashCreator, GatewayServer } from 'slash-create'
import path from 'path'
import CatLoggr from 'cat-loggr/ts'
import {
  Client,
  GatewayDispatchEvents,
  Events,
  Guild,
  Message,
  GuildMember,
  TextChannel,
  EmbedBuilder,
  messageLink
} from 'discord.js'

const client = new Client({ intents: [131071] })

let dotenvPath = path.join(process.cwd(), '.env')
if (path.parse(process.cwd()).name === 'dist') dotenvPath = path.join(process.cwd(), '..', '.env')

dotenv.config({ path: dotenvPath })

const logger = new CatLoggr().setLevel(process.env.COMMANDS_DEBUG === 'true' ? 'debug' : 'info')
const creator = new SlashCreator({
  client,
  applicationID: process.env.APPLICATION_ID ?? 'AASDF',
  publicKey: process.env.PUBLIC_KEY,
  token: process.env.TOKEN
})

creator.on('debug', (message) => logger.log(message))
creator.on('warn', (message) => logger.warn(message))
creator.on('error', (error) => logger.error(error))
creator.on('synced', () => logger.info('Commands synced!'))
creator.on('commandRun', (command, _, ctx) =>
  logger.info(`${ctx.user.username}#${ctx.user.discriminator} (${ctx.user.id}) ran command ${command.commandName}`)
)
creator.on('commandRegister', (command) => logger.info(`Registered command ${command.commandName}`))
creator.on('commandError', (command, error) => logger.error(`Command ${command.commandName}:`, error))

creator
  .withServer(new GatewayServer((handler) => client.ws.on(GatewayDispatchEvents.InteractionCreate, handler)))
  .registerCommandsIn(path.join(__dirname, 'commands'))
  .syncCommands()

client.once('ready', async () => console.log('ready!'))

client.on(Events.MessageCreate, async (msg: Message) => {
  if (msg.channel.id == '1164025412574265364' && !msg.content.startsWith('e')) {
    const m = await msg.channel.send(`<@${msg.author.id}> e`)
    await msg.delete()
    await new Promise((r) => setTimeout(r, 2000))
    await m.delete()
  }
})

client.login(process.env.TOKEN)
